@@ -35,6 +35,7 @@ import statistics
 import abstract
 import os
 import cfg, utils
+import webbrowser
 
 class RunExternalFailed(Exception):
     def __init__(self, v):
@@ -99,20 +100,25 @@ class SolfegeApp(cfg.ConfigUtils):
         """See default.config for rcfileversion values, meanings and
         a description of how to add config variables.
         """
-        if cfg.get_int("app/rcfileversion") > 3:
+        if cfg.get_int("app/rcfileversion") > 5:
             cfg.drop_user_config()
-        if cfg.get_int("app/rcfileversion") == 1:
+            return
+        if cfg.get_int("app/rcfileversion") <= 1:
             if not "example-files" in cfg.get_string('config/lessoncollections'):
                 cfg.set_string('config/lessoncollections', 
                     "%s example-files" % cfg.get_string('config/lessoncollections'))
-            cfg.set_int("app/rcfileversion", 2)
-        if cfg.get_int("app/rcfileversion") == 2:
+        if cfg.get_int("app/rcfileversion") <= 2:
             cfg.del_key("sound/commandline")
-            cfg.set_int("app/rcfileversion", 3)
+        if cfg.get_int("app/rcfileversion") <= 3:
+            cfg.set_list("config/lessoncollections",
+                cfg.get_string("config/lessoncollections").split())
+        if cfg.get_int("app/rcfileversion") <= 4:
+            cfg.del_key("config/web_browser")
+        cfg.set_int("app/rcfileversion", 5)
     def setup_sound(self):
         if sys.platform == 'win32' and \
                     cfg.get_string("sound/type") == "sequencer-device":
-            # just in case c:\home\solfegercX.Y is wrong
+            # just in case c:\home\.solfegerc is wrong
             cfg.set_string("sound/type", "winsynth")
         if '--no-sound' in self.m_argv \
            or cfg.get_string("sound/type") == "fake-synth":
@@ -137,8 +143,8 @@ the preferences window.
 """)
         elif cfg.get_string("sound/type") == "sequencer-device":
             if not configureoutput.HAVE_LINUX_AWE_VOICE_H and \
-               cfg.get_string("sound/card_info") == "awe":
-                       cfg.set_string("sound/card_info", "");
+                    cfg.get_string("sound/card_info") == "awe":
+                cfg.set_string("sound/card_info", "");
             try:
                 soundcard.initialise_devicefile(
                              cfg.get_string("sound/device_file"),
@@ -208,11 +214,11 @@ It is also possible that the OS sound setup is incorrect.
                         self.m_ui.display_error_message("Lessonfile not found:\n%s" % filepath)
                         return
                 if (self.m_ui.m_viewer == 'docviewer'
-                    and self.m_running_exercise is not None
-                    and self.m_running_exercise != fn) or \
-                   (self.m_ui.m_viewer != 'docviewer'):
-                       self.m_ui.box_dict[self.m_running_exercise].on_end_practise()
-                       self.m_running_exercise = None
+                           and self.m_running_exercise is not None
+                           and self.m_running_exercise != fn) or \
+                          (self.m_ui.m_viewer != 'docviewer'):
+                    self.m_ui.box_dict[self.m_running_exercise].on_end_practise()
+                    self.m_running_exercise = None
                 _old_viewer = self.m_ui.m_viewer
                 if fn not in self.m_teachers:
                     new_ex = True
@@ -230,7 +236,7 @@ It is also possible that the OS sound setup is incorrect.
                     new_ex = False
                     self.m_teachers[fn].configure_exercise(lessoncollection, lessonfile, config)
                 self.m_ui.activate_exercise(href)
-                if not new_ex:
+                if not new_ex and 'update_gui_after_lessonfile_change' in dir(self.m_ui.box_dict[fn]):
                     self.m_ui.box_dict[fn].update_gui_after_lessonfile_change()
                 if not (_old_viewer == 'docviewer'
                         and self.m_running_exercise is not None
@@ -238,7 +244,7 @@ It is also possible that the OS sound setup is incorrect.
                     self.m_ui.box_dict[self.m_ui.m_viewer].on_start_practise()
                 self.m_running_exercise = fn
         elif protocol == 'http':
-            os.system(self.get_string("config/web_browser") % href)
+            webbrowser.open_new(href)
         elif protocol == 'mailto':
             os.system(self.get_string("config/mua") % href)
         else:
