@@ -179,12 +179,6 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
         page_vbox.pack_start(box, False)
         sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
 
-        self.g_web_browser = gtk.Entry()
-        self.g_web_browser.set_text(self.get_string("config/web_browser"))
-        self.g_web_browser.connect('changed', self.on_changed)
-        box = gu.hig_label_widget(_("_Web browser:"), self.g_web_browser, sizegroup)
-        category_vbox.pack_start(box)
-
         self.g_mail_program = gtk.Entry()
         self.g_mail_program.set_text(self.get_string("config/mua"))
         self.g_mail_program.connect('changed', self.on_changed)
@@ -462,7 +456,6 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
             self.set_bool('gui/mainwin_user_resizeable',
                           self.g_mainwin_user_resizeable.get_active())
             self.m_app.m_ui.set_resizable(self.get_bool('gui/mainwin_user_resizeable'))
-            self.set_string("config/web_browser", self.g_web_browser.get_text())
             self.set_string("config/mua", self.g_mail_program.get_text())
         if pagenum == 3:
             self.set_bool('config/picky_on_new_question',
@@ -478,9 +471,9 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
             elif self.g_device_radio.get_active():
                 if sys.platform != 'win32' and configureoutput.HAVE_LINUX_AWE_VOICE_H and \
                     self.g_awe_checkbutton.get_active():
-                      card_info = "awe"
+                    card_info = "awe"
                 else:
-                     card_info = ""
+                    card_info = ""
                 try:
                     if sys.platform == 'win32':
                         soundcard.initialise_winsynth(self.g_synth_num.get_value_as_int())
