@@ -18,7 +18,7 @@
 __exercise_data__ = {
     'exercise_name': 'harmonic-interval',
     'menu_path': '%s/%s' % (_("_Intervals"), _("_Harmonic interval")),
-    'icon': 'graphics/harmonicinterval24.png',
+    'stock-icon': 'solfege-harmonic-interval',
     'toolbar': 2,
 }
 import exercise_setup
