@@ -32,7 +32,7 @@ import gtk, pango
 import htmllib, formatter
 import i18n
 
-import string, re, os
+import re, os
 import pyscript
 import configureoutput
 import cfg
@@ -150,7 +150,7 @@ class HTMLWriter(formatter.NullWriter):
         tags = ['normal', '%s-margin%i' % self.m_margin]
         if self.m_link:
             if not self._para_is_new:
-                apply(buf.insert_with_tags_by_name, [buf.get_end_iter(), ' ']+ tags)
+                buf.insert_with_tags_by_name(*[buf.get_end_iter(), ' ']+ tags)
                 txt = txt.strip()
             tags.append('link')
             self._para_is_new = 0
