@@ -15,6 +15,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+__exercise_data__ = {
+    'exercise_name': 'melodic-interval',
+    'menu_path': '%s/%s' % (_("_Intervals"), _("_Melodic intervals")),
+    'stock-icon': 'solfege-melodic-interval',
+    'toolbar': 3,
+}
+import exercise_setup
+exercise_setup.register_exercise(__exercise_data__)
+
 import gtk, gnome
 import gu, widgets, inputwidgets
 import abstract, const
@@ -22,8 +31,9 @@ import statistics, statisticsviewer
 import soundcard, utils, mpd
 
 class Teacher(abstract.MelodicIntervalTeacher):
-    def __init__(self, exname, app):
-        abstract.MelodicIntervalTeacher.__init__(self, exname, app)
+    exercise_data = __exercise_data__
+    def __init__(self, exname, app, config):
+        abstract.MelodicIntervalTeacher.__init__(self, exname, app, config)
         self.m_statistics = statistics.IntervalStatistics(self)
         self.m_timeout_handle = None
     def give_up(self):
@@ -66,7 +76,7 @@ class Gui(abstract.IntervalGui):
         self.config_box.pack_start(self.g_mici, False, False)
         self.config_box.pack_start(gtk.HBox(), False,
                                    padding=gnome.ui.PAD_SMALL)
-        hbox = gu.bHBox(self.config_box, False, False)
+        hbox = gu.bHBox(self.config_box, False)
         hbox.set_spacing(gnome.ui.PAD)
         hbox.pack_start(gtk.Label(_("Try to keep question with range from")),
                         False)
